==> apache-kylin-5.0.0-source-release.zip: apache-kylin-5.0.0/kystudio/src/components/studio/InternalTable/Setting/locales.js <==
export default {
  en: {
    dialogTitle: 'Internal Table Settings',
    settingDesc: 'After you set the time partition column, you can load data in incremental or full mode. Non-partitioned tables only support full load. Note that if incremental loading is required, set the partitioned column to be the same as the data source table level partition and to be a date-type column',
    partitionOptionsTitle: 'Please choose the partition column',
    timePartitionFormatTitle: 'Time column format',
    bucketColumnTitle: 'Please choose the bucket column',
    bucketCountTitle: 'Please set the count of bucket',
    addNativeTableAttributeTitle: 'Set ordering column',
    attributeSettingColumnTitle: 'Column',
    attributeSettingPrimaryTitle: 'Primary Key',
    attributeSettingSortByTitle: 'Sort By Key',
    attributeSettingTips: 'You can set one or more columns to PrimaryKey and SortByKey. Doing so affects the column sorting of the data store file and improves the query performance in some scenarios. Note that to set PrimaryKey, SortByKey must be set, and PrimaryKey is the prefix subset of SortByKey',
    partitionDefaultOptionLabel: 'No Partition',
    bucketDefaultOptionLabel: 'No Bucket Column',
    confirmTitle: 'Save the settings of internal table',
    confirmPrompt: 'Do you want to save this modification? After saving, the running internal table data loading task will be stopped.',
    confirmCreatePrompt: 'Do you want to create internal table?',
    validateErrorSelect: 'Please select one',
    validateErrorNumber: 'Please input integer from 1 to 5000',
    saveFailed: 'Saving failed!',
    saveSuccess: 'Saving success!',
    createSuccess: 'Creating success, please go to Internal Table module for modifying and view details.'
  },
  'zh-cn': {
    dialogTitle: '内表设置',
    settingDesc: '设置时间分区列后可以使用增量或全量方式加载数据，非分区表仅支持全量加载。请注意，如需增量加载，请设置分区列与数据源表一级分区保持一致，且为日期类型列',
    partitionOptionsTitle: '请选择分区列',
    timePartitionFormatTitle: '时间分区列格式',
    bucketColumnTitle: '设置分桶列',
    bucketCountTitle: '设置分桶数',
    addNativeTableAttributeTitle: '设置排序列',
    attributeSettingColumnTitle: 'Column',
    attributeSettingPrimaryTitle: 'Primary Key',
    attributeSettingSortByTitle: 'Sort By Key',
    attributeSettingTips: '可以将一个或多个列设置为PrimaryKey和SortByKey，这样做会影响数据存储文件的列排序，从而提升某些场景的查询性能。请注意，设置PrimaryKey 则必须设置SortByKey，且PrimaryKey是SortByKey的前缀子集',
    partitionDefaultOptionLabel: '无分区',
    bucketDefaultOptionLabel: '无分桶列',
    confirmTitle: '保存内表设置',
    confirmPrompt: '确认要保存此次修改么？保存后正在跑的内表数据加载任务会被中止。',
    confirmCreatePrompt: '确认要创建内表么？',
    validateErrorSelect: '请选择',
    validateErrorNumber: '请输入1到5000整数',
    saveFailed: '保存失败!',
    saveSuccess: '保存成功。',
    createSuccess: '内表创建成功，请前往内表模块修改信息和查看详情。'
  }
}

==> apache-kylin-5.0.3-source-release.zip: apache-kylin-5.0.3/kystudio/src/components/studio/InternalTable/Setting/locales.js <==
export default {
  en: {
    dialogTitle: 'Internal Table Settings',
    settingDesc: 'Please note that if incremental loading is required, set the partition column as a date type, or other types that can be converted to dates, and set the correct time partition column format.',
    partitionOptionsTitle: 'Please choose the partition column',
    timePartitionFormatTitle: 'Time column format',
    bucketColumnTitle: 'Please choose the bucket column',
    bucketCountTitle: 'Please set the count of bucket',
    addNativeTableAttributeTitle: 'Set ordering column',
    attributeSettingColumnTitle: 'Column',
    attributeSettingPrimaryTitle: 'Primary Key',
    attributeSettingSortByTitle: 'Sort By Key',
    attributeSettingTips: 'You can set one or more columns to PrimaryKey and SortByKey. Doing so affects the column sorting of the data store file and improves the query performance in some scenarios. Note that to set PrimaryKey, SortByKey must be set, and PrimaryKey is the prefix subset of SortByKey',
    partitionDefaultOptionLabel: 'No Partition',
    bucketDefaultOptionLabel: 'No Bucket Column',
    confirmTitle: 'Save the settings of internal table',
    confirmPrompt: 'Do you want to save this modification? After saving, the running internal table data loading task will be stopped.',
    confirmCreatePrompt: 'Do you want to create internal table?',
    validateErrorSelect: 'Please select one',
    validateErrorNumber: 'Please input integer from 1 to 5000',
    saveFailed: 'Saving failed!',
    saveSuccess: 'Saving success!',
    createSuccess: 'Creating success, please go to Internal Table module for modifying and view details.'
  },
  'zh-cn': {
    dialogTitle: '内表设置',
    settingDesc: '请注意，如需增量加载，请设置分区列为日期类型，或可以转为日期的其他类型，并设置正确的时间分区列格式。',
    partitionOptionsTitle: '请选择分区列',
    timePartitionFormatTitle: '时间分区列格式',
    bucketColumnTitle: '设置分桶列',
    bucketCountTitle: '设置分桶数',
    addNativeTableAttributeTitle: '设置排序列',
    attributeSettingColumnTitle: 'Column',
    attributeSettingPrimaryTitle: 'Primary Key',
    attributeSettingSortByTitle: 'Sort By Key',
    attributeSettingTips: '可以将一个或多个列设置为PrimaryKey和SortByKey，这样做会影响数据存储文件的列排序，从而提升某些场景的查询性能。请注意，设置PrimaryKey 则必须设置SortByKey，且PrimaryKey是SortByKey的前缀子集',
    partitionDefaultOptionLabel: '无分区',
    bucketDefaultOptionLabel: '无分桶列',
    confirmTitle: '保存内表设置',
    confirmPrompt: '确认要保存此次修改么？保存后正在跑的内表数据加载任务会被中止。',
    confirmCreatePrompt: '确认要创建内表么？',
    validateErrorSelect: '请选择',
    validateErrorNumber: '请输入1到5000整数',
    saveFailed: '保存失败!',
    saveSuccess: '保存成功。',
    createSuccess: '内表创建成功，请前往内表模块修改信息和查看详情。'
  }
}
